Enum Delcmp
#[repr(u8)]pub enum Delcmp {
Standard = 0,
Capture1 = 1,
CaptureXCompare1 = 2,
CaptureXCompare3 = 3,
}Variants
Standard = 0
CMP register is always active (standard compare mode)
Capture1 = 1
CMP is recomputed and is active following a capture 1 event
CaptureXCompare1 = 2
CMP is recomputed and is active following a capture 1 event or a Compare 1 match
CaptureXCompare3 = 3
CMP is recomputed and is active following a capture 1 event or a Compare 3 match
Implementations